@@ -195,7 +195,7 @@ func Test_BreakingChangesInvalidIgnoreFile(t *testing.T) {
 
 func Test_ComposedMode(t *testing.T) {
 	var stdout bytes.Buffer
-	require.Zero(t, internal.Run(cmdToArgs("oasdiff diff ../data/composed/base/*.yaml ../data/composed/revision/*.yaml --composed --exclude-elements endpoints"), &stdout, io.Discard))
+	require.Zero(t, internal.Run(cmdToArgs("oasdiff diff ../data/composed/base/*.yaml ../data/composed/revision/*.yaml --composed --exclude-elements endpoints,extensions"), &stdout, io.Discard))
 	var bc interface{}
 	require.NoError(t, yaml.Unmarshal(stdout.Bytes(), &bc))
 	require.Equal(t, map[string]interface{}{"paths": map[string]interface{}{"deleted": []interface{}{"/api/old-test"}}}, bc)
@@ -301,7 +301,3 @@ func Test_ColorWithNonTextFormat(t *testing.T) {
 	require.Equal(t, 100, internal.Run(cmdToArgs("oasdiff changelog ../data/allof/simple.yaml ../data/allof/revision.yaml -f yaml --color always"), io.Discard, &stderr))
 	require.Equal(t, "Error: --color flag is only relevant with 'text' or 'singleline' formats\n", stderr.String())
 }
-
-func Test_Delta(t *testing.T) {
-	require.Zero(t, internal.Run(cmdToArgs("oasdiff delta ../data/simple1.yaml ../data/simple2.yaml"), io.Discard, io.Discard))
-}
